==> termice-1.0.6.tgz: package/readme.md <==
# termice
Simple terminal icecast player

![Screenshot_20190406_150249](https://user-images.githubusercontent.com/14959143/55671226-5020e480-587d-11e9-90be-a090ef096d98.png)
![Screenshot_20190406_131441](https://user-images.githubusercontent.com/14959143/55670094-92432980-586f-11e9-883d-2ba5629d73c3.png)

# Install
`npm install termice -g`
<br>Alternatively there are .deb packages for debian based platforms

# Usage
Just launch it
<br>For startup options, run the program with -h

# Available stream directories
- Icecast
- Shoutcast
- radio-browser

# Configuration
Currently, termice relies on Mplayer in order to work
<br>Mplayer path, intial query and css styes can be set up at src/conf folder
<br>or /etc/termice in the case of deb packages

# Build
- Install dependencies with npm i
- Run tsc in order to generate src/js folder

# License
Copyright (c) 2019 Alvaro Fernandez
<br>This program is free software: you can redistribute it and/or modify
<br>it under the terms of the GNU General Public License as published by
<br>the Free Software Foundation, either version 3 of the License, or
<br>(at your option) any later version.
<br>
<br>This program is distributed in the hope that it will be useful,
<br>but WITHOUT ANY WARRANTY; without even the implied warranty of
<br>MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
<br>GNU General Public License for more details.
<br>
<br>You should have received a copy of the GNU General Public License
<br>along with this program.  If not, see {@link https://www.gnu.org/licenses/}.

# Special thanks
The authors of every module used in this program

# Contact mail
nishinishi9999 at protonmail dot com

==> termice-1.1.0.tgz: package/readme.md <==
# Termice

## Description
Simple terminal icecast and internet radio stream player.

## Screenshots

![Screenshot_20190406_150249](https://user-images.githubusercontent.com/14959143/55671226-5020e480-587d-11e9-90be-a090ef096d98.png)
![Screenshot_20190406_131441](https://user-images.githubusercontent.com/14959143/55670094-92432980-586f-11e9-883d-2ba5629d73c3.png)

## Install
`npm install termice -g`<br>
Or if you dont want to install it: `npx termice`
<br>Alternatively there are .deb packages for debian based platforms

## Usage
Just launch it
<br>For startup options, run the program with -h

## Available stream directories
- Icecast
- Shoutcast
- radio-browser

## Configuration
Currently, termice relies on Mplayer in order to work
<br>Mplayer path, intial query and css styes can be set up at src/conf folder
<br>or /etc/termice in the case of deb packages

## Build
- Install dependencies with npm i
- Build with npm run build
- Run with npm start

## License
Copyright (c) 2019 Alvaro Fernandez
<br>This program is free software: you can redistribute it and/or modify
<br>it under the terms of the GNU General Public License as published by
<br>the Free Software Foundation, either version 3 of the License, or
<br>(at your option) any later version.
<br>
<br>This program is distributed in the hope that it will be useful,
<br>but WITHOUT ANY WARRANTY; without even the implied warranty of
<br>MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
<br>GNU General Public License for more details.
<br>
<br>You should have received a copy of the GNU General Public License
<br>along with this program.  If not, see {@link https://www.gnu.org/licenses/}.

## Special thanks
The authors of every module used in this program

## Contact mail
nishinishi9999 at protonmail dot com
